@@ -27,17 +27,17 @@ class TestBronze:
                                     storage_bronze, storage_silver, input_data_param_v3, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
 
-    def test_bronze(self):
+    def load_data_v1(self):
         self.delta_lake_v1.initialize_config_storage()
         self.delta_lake_v1.validate_tables()
         self.delta_lake_v1.create_colums_merge()
         self.delta_lake_v1.load_data_csv(self.delta_lake_v1.input_data)
-        self.delta_lake_v1.initialize_config_storage()
         self.delta_lake_v1.merge()
         df = self.delta_lake_v1.spark.sql("select * from {0}.{1}".format(self.delta_lake_v1.database,
-                                                                          self.delta_lake_v1.table_name))
+                                                                         self.delta_lake_v1.table_name))
         assert df.count() == self.number_items_valide_v1
 
+    def load_data_v2(self):
         self.delta_lake_v2.initialize_config_storage()
         self.delta_lake_v2.validate_tables()
         self.delta_lake_v2.create_colums_merge()
@@ -45,9 +45,10 @@ class TestBronze:
         self.delta_lake_v2.initialize_config_storage()
         self.delta_lake_v2.merge()
         df = self.delta_lake_v2.spark.sql("select * from {0}.{1}".format(self.delta_lake_v1.database,
-                                                                          self.delta_lake_v1.table_name))
+                                                                         self.delta_lake_v1.table_name))
         assert df.count() == self.number_items_valide_v2
 
+    def load_data_v3(self):
         self.delta_lake_v3.initialize_config_storage()
         self.delta_lake_v3.validate_tables()
         self.delta_lake_v3.create_colums_merge()
@@ -55,11 +56,14 @@ class TestBronze:
         self.delta_lake_v3.initialize_config_storage()
         self.delta_lake_v3.merge()
         df = self.delta_lake_v3.spark.sql("select {0} From {1}.{2} where {3}={4}".format(self.colum_validate_data,
-                                                                            self.delta_lake_v1.database,
-                                                                            self.delta_lake_v1.table_name,
-                                                                            self.colum_filter, self.value_filter))
+                                                                                         self.delta_lake_v1.database,
+                                                                                         self.delta_lake_v1.table_name,
+                                                                                         self.colum_filter,
+                                                                                         self.value_filter))
         value = df.collect()
         assert value[0][self.colum_validate_data] == self.value_validate_data
+
+    def initializar_test(self):
         self.delta_lake_v1.spark.sql("DROP TABLE {0}.{1}".format(self.delta_lake_v1.database,
                                                                  self.delta_lake_v1.table_name))
         list_file = self.util.list_folder_delta_lake(self.delta_lake_v1.mount_data)
